{"linux/fs.h", "FIBMAP", 0x1},
{"linux/fs.h", "FIGETBSZ", 0x2},
{"linux/fd.h", "FDCLRPRM", 0x241},
{"linux/fd.h", "FDMSGON", 0x245},
{"linux/fd.h", "FDMSGOFF", 0x246},
{"linux/fd.h", "FDFMTBEG", 0x247},
{"linux/fd.h", "FDFMTEND", 0x249},
{"linux/fd.h", "FDSETEMSGTRESH", 0x24a},
{"linux/fd.h", "FDFLUSH", 0x24b},
{"linux/fd.h", "FDRESET", 0x254},
{"linux/fd.h", "FDWERRORCLR", 0x256},
{"linux/fd.h", "FDRAWCMD", 0x258},
{"linux/fd.h", "FDTWADDLE", 0x259},
{"linux/fd.h", "FDEJECT", 0x25a},
{"linux/ip_fw.h", "IP_FW_TYPE", 0x300},
{"linux/quota.h", "Q_GETQUOTA", 0x300},
{"linux/hdreg.h", "HDIO_GETGEO", 0x301},
{"linux/hdreg.h", "HDIO_GET_UNMASKINTR", 0x302},
{"linux/hdreg.h", "HDIO_GET_MULTCOUNT", 0x304},
{"linux/hdreg.h", "HDIO_GET_IDENTITY", 0x307},
{"linux/hdreg.h", "HDIO_GET_KEEPSETTINGS", 0x308},
{"linux/hdreg.h", "HDIO_GET_32BIT", 0x309},
{"linux/hdreg.h", "HDIO_GET_NOWERR", 0x30a},
{"linux/hdreg.h", "HDIO_GET_DMA", 0x30b},
{"linux/hdreg.h", "HDIO_DRIVE_CMD", 0x31f},
{"linux/hdreg.h", "HDIO_SET_MULTCOUNT", 0x321},
{"linux/hdreg.h", "HDIO_SET_UNMASKINTR", 0x322},
{"linux/hdreg.h", "HDIO_SET_KEEPSETTINGS", 0x323},
{"linux/hdreg.h", "HDIO_SET_32BIT", 0x324},
{"linux/hdreg.h", "HDIO_SET_NOWERR", 0x325},
{"linux/hdreg.h", "HDIO_SET_DMA", 0x326},
{"linux/hdreg.h", "HDIO_SET_PIO_MODE", 0x327},
{"linux/umsdos_fs.h", "UMSDOS_READDIR_DOS", 0x4d2},
{"linux/umsdos_fs.h", "UMSDOS_UNLINK_DOS", 0x4d3},
{"linux/umsdos_fs.h", "UMSDOS_RMDIR_DOS", 0x4d4},
{"linux/umsdos_fs.h", "UMSDOS_STAT_DOS", 0x4d5},
{"linux/umsdos_fs.h", "UMSDOS_CREAT_EMD", 0x4d6},
{"linux/umsdos_fs.h", "UMSDOS_UNLINK_EMD", 0x4d7},
{"linux/umsdos_fs.h", "UMSDOS_READDIR_EMD", 0x4d8},
{"linux/umsdos_fs.h", "UMSDOS_GETVERSION", 0x4d9},
{"linux/umsdos_fs.h", "UMSDOS_INIT_EMD", 0x4da},
{"linux/umsdos_fs.h", "UMSDOS_DOS_SETUP", 0x4db},
{"linux/umsdos_fs.h", "UMSDOS_RENAME_DOS", 0x4dc},
{"linux/quota.h", "Q_SYNC", 0x600},
{"linux/lp.h", "LPCHAR", 0x601},
{"linux/lp_m68k.h", "LPCHAR", 0x601},
{"linux/lp.h", "LPTIME", 0x602},
{"linux/lp_m68k.h", "LPTIME", 0x602},
{"linux/lp.h", "LPABORT", 0x604},
{"linux/lp_m68k.h", "LPABORT", 0x604},
{"linux/lp.h", "LPSETIRQ", 0x605},
{"linux/lp_m68k.h", "LPSETIRQ", 0x605},
{"linux/lp.h", "LPGETIRQ", 0x606},
{"linux/lp_m68k.h", "LPGETIRQ", 0x606},
{"linux/lp.h", "LPWAIT", 0x608},
{"linux/lp_m68k.h", "LPWAIT", 0x608},
{"linux/lp.h", "LPCAREFUL", 0x609},
{"linux/lp_m68k.h", "LPCAREFUL", 0x609},
{"linux/lp.h", "LPABORTOPEN", 0x60a},
{"linux/lp_m68k.h", "LPABORTOPEN", 0x60a},
{"linux/lp.h", "LPGETSTATUS", 0x60b},
{"linux/lp_m68k.h", "LPGETSTATUS", 0x60b},
{"linux/lp.h", "LPRESET", 0x60c},
{"linux/lp_m68k.h", "LPRESET", 0x60c},
{"linux/lp.h", "LPGETSTATS", 0x60d},
{"linux/lp.h", "LPGETFLAGS", 0x60e},
{"linux/md.h", "REGISTER_DEV", 0x901},
{"linux/md.h", "START_MD", 0x902},
{"linux/md.h", "STOP_MD", 0x903},
{"linux/md.h", "MD_INVALID", 0x904},
{"linux/md.h", "MD_VALID", 0x905},
{"linux/fs.h", "BLKROSET", 0x125d},
{"linux/fs.h", "BLKROGET", 0x125e},
{"linux/fs.h", "BLKRRPART", 0x125f},
{"linux/fs.h", "BLKGETSIZE", 0x1260},
{"linux/fs.h", "BLKFLSBUF", 0x1261},
{"linux/fs.h", "BLKRASET", 0x1262},
{"linux/fs.h", "BLKRAGET", 0x1263},
{"linux/scc.h", "TIOCSCCCFG", 0x2200},
{"linux/scc.h", "TIOCSCCINI", 0x2201},
{"linux/scc.h", "TIOCCHANINI", 0x2202},
{"linux/scc.h", "TIOCCHANMEM", 0x2210},
{"linux/scc.h", "TIOCGKISS", 0x2282},
{"linux/scc.h", "TIOCSKISS", 0x2283},
{"linux/scc.h", "TIOCSCCSTAT", 0x2284},
{"linux/apm_bios.h", "APM_IOC_STANDBY", 0x4101},
{"linux/apm_bios.h", "APM_IOC_SUSPEND", 0x4102},
{"linux/soundcard.h", "SNDCTL_COPR_RESET", 0x4300},
{"linux/fb.h", "FBIOGET_VSCREENINFO", 0x4600},
{"linux/fb.h", "FBIOPUT_VSCREENINFO", 0x4601},
{"linux/fb.h", "FBIOGET_FSCREENINFO", 0x4602},
{"linux/fb.h", "FBIOGETCMAP", 0x4604},
{"linux/fb.h", "FBIOPUTCMAP", 0x4605},
{"linux/fb.h", "FBIOPAN_DISPLAY", 0x4606},
{"linux/fb.h", "FBIOGET_FCURSORINFO", 0x4607},
{"linux/fb.h", "FBIOGET_VCURSORINFO", 0x4608},
{"linux/fb.h", "FBIOPUT_VCURSORINFO", 0x4609},
{"linux/fb.h", "FBIOGET_CURSORSTATE", 0x460a},
{"linux/fb.h", "FBIOPUT_CURSORSTATE", 0x460b},
{"linux/fb.h", "FBCMD_DRAWLINE", 0x4621},
{"linux/fb.h", "FBCMD_MOVE", 0x4622},
{"linux/isdn.h", "IIOCNETAIF", 0x4901},
{"linux/isdn.h", "IIOCNETDIF", 0x4902},
{"linux/isdn.h", "IIOCNETSCF", 0x4903},
{"linux/isdn.h", "IIOCNETGCF", 0x4904},
{"linux/isdn.h", "IIOCNETANM", 0x4905},
{"linux/isdn.h", "IIOCNETDNM", 0x4906},
{"linux/isdn.h", "IIOCNETGNM", 0x4907},
{"linux/isdn.h", "IIOCGETSET", 0x4908},
{"linux/isdn.h", "IIOCSETSET", 0x4909},
{"linux/isdn.h", "IIOCSETVER", 0x490a},
{"linux/isdn.h", "IIOCNETHUP", 0x490b},
{"linux/isdn.h", "IIOCSETGST", 0x490c},
{"linux/isdn.h", "IIOCSETBRJ", 0x490d},
{"linux/isdn.h", "IIOCSIGPRF", 0x490e},
{"linux/isdn.h", "IIOCGETPRF", 0x490f},
{"linux/isdn.h", "IIOCSETPRF", 0x4910},
{"linux/isdn.h", "IIOCGETMAP", 0x4911},
{"linux/isdn.h", "IIOCSETMAP", 0x4912},
{"linux/isdn.h", "IIOCNETASL", 0x4913},
{"linux/isdn.h", "IIOCNETDIL", 0x4914},
{"linux/isdn.h", "IIOCGETCPS", 0x4915},
{"linux/isdn.h", "IIOCNETALN", 0x4920},
{"linux/isdn.h", "IIOCNETDLN", 0x4921},
{"linux/isdn.h", "IIOCDBGVAR", 0x497f},
{"linux/isdn.h", "IIOCDRVCTL", 0x4980},
{"linux/kd.h", "KIOCSOUND", 0x4b2f},
{"linux/kd.h", "KDMKTONE", 0x4b30},
{"linux/kd.h", "KDGETLED", 0x4b31},
{"linux/kd.h", "KDSETLED", 0x4b32},
{"linux/kd.h", "KDGKBTYPE", 0x4b33},
{"linux/kd.h", "KDADDIO", 0x4b34},
{"linux/kd.h", "KDDELIO", 0x4b35},
{"linux/kd.h", "KDENABIO", 0x4b36},
{"linux/kd.h", "KDDISABIO", 0x4b37},
{"linux/kd.h", "KDSETMODE", 0x4b3a},
{"linux/kd.h", "KDGETMODE", 0x4b3b},
{"linux/kd.h", "KDMAPDISP", 0x4b3c},
{"linux/kd.h", "KDUNMAPDISP", 0x4b3d},
{"linux/kd.h", "GIO_SCRNMAP", 0x4b40},
{"linux/kd.h", "PIO_SCRNMAP", 0x4b41},
{"linux/kd.h", "KDGKBMODE", 0x4b44},
{"linux/kd.h", "KDSKBMODE", 0x4b45},
{"linux/kd.h", "KDGKBENT", 0x4b46},
{"linux/kd.h", "KDSKBENT", 0x4b47},
{"linux/kd.h", "KDGKBSENT", 0x4b48},
{"linux/kd.h", "KDSKBSENT", 0x4b49},
{"linux/kd.h", "KDGKBDIACR", 0x4b4a},
{"linux/kd.h", "KDSKBDIACR", 0x4b4b},
{"linux/kd.h", "KDGETKEYCODE", 0x4b4c},
{"linux/kd.h", "KDSETKEYCODE", 0x4b4d},
{"linux/kd.h", "KDSIGACCEPT", 0x4b4e},
{"linux/kd.h", "GIO_FONT", 0x4b60},
{"linux/kd.h", "PIO_FONT", 0x4b61},
{"linux/kd.h", "KDGKBMETA", 0x4b62},
{"linux/kd.h", "KDSKBMETA", 0x4b63},
{"linux/kd.h", "KDGKBLED", 0x4b64},
{"linux/kd.h", "KDSKBLED", 0x4b65},
{"linux/kd.h", "GIO_UNIMAP", 0x4b66},
{"linux/kd.h", "PIO_UNIMAP", 0x4b67},
{"linux/kd.h", "PIO_UNIMAPCLR", 0x4b68},
{"linux/kd.h", "GIO_UNISCRNMAP", 0x4b69},
{"linux/kd.h", "PIO_UNISCRNMAP", 0x4b6a},
{"linux/kd.h", "GIO_FONTX", 0x4b6b},
{"linux/kd.h", "PIO_FONTX", 0x4b6c},
{"linux/kd.h", "PIO_FONTRESET", 0x4b6d},
{"linux/kd.h", "GIO_CMAP", 0x4b70},
{"linux/kd.h", "PIO_CMAP", 0x4b71},
{"linux/loop.h", "LOOP_SET_FD", 0x4c00},
{"linux/loop.h", "LOOP_CLR_FD", 0x4c01},
{"linux/loop.h", "LOOP_SET_STATUS", 0x4c02},
{"linux/loop.h", "LOOP_GET_STATUS", 0x4c03},
{"linux/soundcard.h", "SNDCTL_DSP_RESET", 0x5000},
{"linux/soundcard.h", "SNDCTL_DSP_SYNC", 0x5001},
{"linux/soundcard.h", "SNDCTL_DSP_POST", 0x5008},
{"linux/soundcard.h", "SNDCTL_DSP_NONBLOCK", 0x500e},
{"linux/soundcard.h", "SNDCTL_DSP_SETSYNCRO", 0x5015},
{"linux/soundcard.h", "SNDCTL_DSP_SETDUPLEX", 0x5016},
{"linux/soundcard.h", "SNDCTL_SEQ_RESET", 0x5100},
{"linux/soundcard.h", "SNDCTL_SEQ_SYNC", 0x5101},
{"linux/soundcard.h", "SNDCTL_SEQ_PANIC", 0x5111},
{"linux/random.h", "RNDZAPENTCNT", 0x5204},
{"linux/random.h", "RNDCLEARPOOL", 0x5206},
{"linux/cdrom.h", "CDROMPAUSE", 0x5301},
{"linux/cdrom.h", "CDROMRESUME", 0x5302},
{"linux/cdrom.h", "CDROMPLAYMSF", 0x5303},
{"linux/cdrom.h", "CDROMPLAYTRKIND", 0x5304},
{"linux/cdrom.h", "CDROMREADTOCHDR", 0x5305},
{"linux/cdrom.h", "CDROMREADTOCENTRY", 0x5306},
{"linux/cdrom.h", "CDROMSTOP", 0x5307},
{"linux/cdrom.h", "CDROMSTART", 0x5308},
{"linux/cdrom.h", "CDROMEJECT", 0x5309},
{"linux/cdrom.h", "CDROMVOLCTRL", 0x530a},
{"linux/cdrom.h", "CDROMSUBCHNL", 0x530b},
{"linux/cdrom.h", "CDROMREADMODE2", 0x530c},
{"linux/cdrom.h", "CDROMREADMODE1", 0x530d},
{"linux/cdrom.h", "CDROMREADAUDIO", 0x530e},
{"linux/cdrom.h", "CDROMEJECT_SW", 0x530f},
{"linux/cdrom.h", "CDROMMULTISESSION", 0x5310},
{"linux/cdrom.h", "CDROM_GET_UPC", 0x5311},
{"linux/cm206.h", "CDROM_GET_UPC", 0x5311},
{"linux/cdrom.h", "CDROMRESET", 0x5312},
{"linux/cm206.h", "CDROMRESET", 0x5312},
{"linux/cdrom.h", "CDROMVOLREAD", 0x5313},
{"linux/cdrom.h", "CDROMREADRAW", 0x5314},
{"linux/cdrom.h", "CDROMREADCOOKED", 0x5315},
{"linux/cdrom.h", "CDROMSEEK", 0x5316},
{"linux/cdrom.h", "CDROMPLAYBLK", 0x5317},
{"linux/cdrom.h", "CDROMREADALL", 0x5318},
{"linux/cdrom.h", "CDROMCLOSETRAY", 0x5319},
{"linux/cdrom.h", "CDROMLOADFROMSLOT", 0x531a},
{"linux/ucdrom.h", "CDROM_SET_OPTIONS", 0x5320},
{"linux/ucdrom.h", "CDROM_CLEAR_OPTIONS", 0x5321},
{"linux/ucdrom.h", "CDROM_SELECT_SPEED", 0x5322},
{"linux/ucdrom.h", "CDROM_SELECT_DISC", 0x5323},
{"linux/ucdrom.h", "CDROM_MEDIA_CHANGED", 0x5325},
{"linux/ucdrom.h", "CDROM_DRIVE_STATUS", 0x5326},
{"linux/ucdrom.h", "CDROM_DISC_STATUS", 0x5327},
{"linux/sbpcd.h", "CDROMAUDIOBUFSIZ", 0x5382},
{"asm/ioctls.h", "TCGETS", 0x5401},
{"asm/ioctls.h", "TCSETS", 0x5402},
{"linux/soundcard.h", "SNDCTL_TMR_START", 0x5402},
{"asm/ioctls.h", "TCSETSW", 0x5403},
{"linux/soundcard.h", "SNDCTL_TMR_STOP", 0x5403},
{"asm/ioctls.h", "TCSETSF", 0x5404},
{"linux/soundcard.h", "SNDCTL_TMR_CONTINUE", 0x5404},
{"asm/ioctls.h", "TCGETA", 0x5405},
{"asm/ioctls.h", "TCSETA", 0x5406},
{"asm/ioctls.h", "TCSETAW", 0x5407},
{"asm/ioctls.h", "TCSETAF", 0x5408},
{"asm/ioctls.h", "TCSBRK", 0x5409},
{"asm/ioctls.h", "TCXONC", 0x540a},
{"asm/ioctls.h", "TCFLSH", 0x540b},
{"asm/ioctls.h", "TIOCEXCL", 0x540c},
{"asm/ioctls.h", "TIOCNXCL", 0x540d},
{"asm/ioctls.h", "TIOCSCTTY", 0x540e},
{"asm/ioctls.h", "TIOCGPGRP", 0x540f},
{"asm/ioctls.h", "TIOCSPGRP", 0x5410},
{"asm/ioctls.h", "TIOCOUTQ", 0x5411},
{"asm/ioctls.h", "TIOCSTI", 0x5412},
{"asm/ioctls.h", "TIOCGWINSZ", 0x5413},
{"asm/ioctls.h", "TIOCSWINSZ", 0x5414},
{"asm/ioctls.h", "TIOCMGET", 0x5415},
{"asm/ioctls.h", "TIOCMBIS", 0x5416},
{"asm/ioctls.h", "TIOCMBIC", 0x5417},
{"asm/ioctls.h", "TIOCMSET", 0x5418},
{"asm/ioctls.h", "TIOCGSOFTCAR", 0x5419},
{"asm/ioctls.h", "TIOCSSOFTCAR", 0x541a},
{"asm/ioctls.h", "FIONREAD", 0x541b},
{"asm/ioctls.h", "TIOCLINUX", 0x541c},
{"asm/ioctls.h", "TIOCCONS", 0x541d},
{"asm/ioctls.h", "TIOCGSERIAL", 0x541e},
{"asm/ioctls.h", "TIOCSSERIAL", 0x541f},
{"asm/ioctls.h", "TIOCPKT", 0x5420},
{"asm/ioctls.h", "FIONBIO", 0x5421},
{"asm/ioctls.h", "TIOCNOTTY", 0x5422},
{"asm/ioctls.h", "TIOCSETD", 0x5423},
{"asm/ioctls.h", "TIOCGETD", 0x5424},
{"asm/ioctls.h", "TCSBRKP", 0x5425},
{"asm/ioctls.h", "TIOCTTYGSTRUCT", 0x5426},
{"asm/ioctls.h", "FIONCLEX", 0x5450},
{"asm/ioctls.h", "FIOCLEX", 0x5451},
{"asm/ioctls.h", "FIOASYNC", 0x5452},
{"asm/ioctls.h", "TIOCSERCONFIG", 0x5453},
{"asm/ioctls.h", "TIOCSERGWILD", 0x5454},
{"asm/ioctls.h", "TIOCSERSWILD", 0x5455},
{"asm/ioctls.h", "TIOCGLCKTRMIOS", 0x5456},
{"asm/ioctls.h", "TIOCSLCKTRMIOS", 0x5457},
{"asm/ioctls.h", "TIOCSERGSTRUCT", 0x5458},
{"asm/ioctls.h", "TIOCSERGETLSR", 0x5459},
{"asm/ioctls.h", "TIOCSERGETMULTI", 0x545a},
{"asm/ioctls.h", "TIOCSERSETMULTI", 0x545b},
{"asm/ioctls.h", "TIOCMIWAIT", 0x545c},
{"asm/ioctls.h", "TIOCGICOUNT", 0x545d},
{"linux/vt.h", "VT_OPENQRY", 0x5600},
{"linux/vt.h", "VT_GETMODE", 0x5601},
{"linux/vt.h", "VT_SETMODE", 0x5602},
{"linux/vt.h", "VT_GETSTATE", 0x5603},
{"linux/vt.h", "VT_SENDSIG", 0x5604},
{"linux/vt.h", "VT_RELDISP", 0x5605},
{"linux/vt.h", "VT_ACTIVATE", 0x5606},
{"linux/vt.h", "VT_WAITACTIVE", 0x5607},
{"linux/vt.h", "VT_DISALLOCATE", 0x5608},
{"linux/vt.h", "VT_RESIZE", 0x5609},
{"linux/vt.h", "VT_RESIZEX", 0x560a},
{"linux/vt.h", "VT_LOCKSWITCH", 0x560b},
{"linux/vt.h", "VT_UNLOCKSWITCH", 0x560c},
{"linux/comstats.h", "COM_GETPORTSTATS", 0x631e},
{"linux/comstats.h", "COM_CLRPORTSTATS", 0x631f},
{"linux/comstats.h", "COM_GETBRDSTATS", 0x6320},
{"linux/comstats.h", "COM_READPORT", 0x6328},
{"linux/comstats.h", "COM_READBOARD", 0x6329},
{"linux/comstats.h", "COM_READPANEL", 0x632a},
{"linux/ncp_fs.h", "NCP_IOC_CONN_LOGGED_IN", 0x6e03},
{"linux/cdk.h", "STL_BINTR", 0x7314},
{"linux/cdk.h", "STL_BSTART", 0x7315},
{"linux/cdk.h", "STL_BSTOP", 0x7316},
{"linux/cdk.h", "STL_BRESET", 0x7317},
{"linux/cdk.h", "STL_GETPFLAG", 0x7350},
{"linux/cdk.h", "STL_SETPFLAG", 0x7351},
{"linux/if_ppp.h", "PPPIOCXFERUNIT", 0x744e},
{"asm/sockios.h", "FIOSETOWN", 0x8901},
{"asm/sockios.h", "SIOCSPGRP", 0x8902},
{"asm/sockios.h", "FIOGETOWN", 0x8903},
{"asm/sockios.h", "SIOCGPGRP", 0x8904},
{"asm/sockios.h", "SIOCATMARK", 0x8905},
{"asm/sockios.h", "SIOCGSTAMP", 0x8906},
{"linux/sockios.h", "SIOCADDRT", 0x890b},
{"linux/sockios.h", "SIOCDELRT", 0x890c},
{"linux/sockios.h", "SIOCGIFNAME", 0x8910},
{"linux/sockios.h", "SIOCSIFLINK", 0x8911},
{"linux/sockios.h", "SIOCGIFCONF", 0x8912},
{"linux/sockios.h", "SIOCGIFFLAGS", 0x8913},
{"linux/sockios.h", "SIOCSIFFLAGS", 0x8914},
{"linux/sockios.h", "SIOCGIFADDR", 0x8915},
{"linux/sockios.h", "SIOCSIFADDR", 0x8916},
{"linux/sockios.h", "SIOCGIFDSTADDR", 0x8917},
{"linux/sockios.h", "SIOCSIFDSTADDR", 0x8918},
{"linux/sockios.h", "SIOCGIFBRDADDR", 0x8919},
{"linux/sockios.h", "SIOCSIFBRDADDR", 0x891a},
{"linux/sockios.h", "SIOCGIFNETMASK", 0x891b},
{"linux/sockios.h", "SIOCSIFNETMASK", 0x891c},
{"linux/sockios.h", "SIOCGIFMETRIC", 0x891d},
{"linux/sockios.h", "SIOCSIFMETRIC", 0x891e},
{"linux/sockios.h", "SIOCGIFMEM", 0x891f},
{"linux/sockios.h", "SIOCSIFMEM", 0x8920},
{"linux/sockios.h", "SIOCGIFMTU", 0x8921},
{"linux/sockios.h", "SIOCSIFMTU", 0x8922},
{"linux/sockios.h", "SIOCSIFHWADDR", 0x8924},
{"linux/sockios.h", "SIOCGIFENCAP", 0x8925},
{"linux/sockios.h", "SIOCSIFENCAP", 0x8926},
{"linux/sockios.h", "SIOCGIFHWADDR", 0x8927},
{"linux/sockios.h", "SIOCGIFSLAVE", 0x8929},
{"linux/sockios.h", "SIOCSIFSLAVE", 0x8930},
{"linux/sockios.h", "SIOCADDMULTI", 0x8931},
{"linux/sockios.h", "SIOCDELMULTI", 0x8932},
{"linux/sockios.h", "SIOCGIFBR", 0x8940},
{"linux/sockios.h", "SIOCSIFBR", 0x8941},
{"linux/sockios.h", "OLD_SIOCDARP", 0x8950},
{"linux/sockios.h", "OLD_SIOCGARP", 0x8951},
{"linux/sockios.h", "OLD_SIOCSARP", 0x8952},
{"linux/sockios.h", "SIOCDARP", 0x8953},
{"linux/sockios.h", "SIOCGARP", 0x8954},
{"linux/sockios.h", "SIOCSARP", 0x8955},
{"linux/sockios.h", "SIOCDRARP", 0x8960},
{"linux/sockios.h", "SIOCGRARP", 0x8961},
{"linux/sockios.h", "SIOCSRARP", 0x8962},
{"linux/sockios.h", "SIOCGIFMAP", 0x8970},
{"linux/sockios.h", "SIOCSIFMAP", 0x8971},
{"linux/sockios.h", "SIOCADDDLCI", 0x8980},
{"linux/sockios.h", "SIOCDELDLCI", 0x8981},
{"linux/sockios.h", "SIOCPROTOPRIVATE", 0x89e0},
{"linux/sockios.h", "SIOCDEVPRIVATE", 0x89f0},
{"linux/sbpcd.h", "DDIOCSDBG", 0x9000},
{"linux/cyclades.h", "CYGETMON", 0x435901},
{"linux/cyclades.h", "CYGETTHRESH", 0x435902},
{"linux/cyclades.h", "CYSETTHRESH", 0x435903},
{"linux/cyclades.h", "CYGETDEFTHRESH", 0x435904},
{"linux/cyclades.h", "CYSETDEFTHRESH", 0x435905},
{"linux/cyclades.h", "CYGETTIMEOUT", 0x435906},
{"linux/cyclades.h", "CYSETTIMEOUT", 0x435907},
{"linux/cyclades.h", "CYGETDEFTIMEOUT", 0x435908},
{"linux/cyclades.h", "CYSETDEFTIMEOUT", 0x435909},
{"linux/ncp_fs.h", "NCP_IOC_GETMOUNTUID", 0x40026e02},
{"linux/soundcard.h", "SNDCTL_DSP_SETTRIGGER", 0x40045010},
{"linux/soundcard.h", "SNDCTL_SEQ_PERCMODE", 0x40045106},
{"linux/soundcard.h", "SNDCTL_SEQ_TESTMIDI", 0x40045108},
{"linux/soundcard.h", "SNDCTL_SEQ_RESETSAMPLES", 0x40045109},
{"linux/soundcard.h", "SNDCTL_SEQ_THRESHOLD", 0x4004510d},
{"linux/soundcard.h", "SNDCTL_FM_4OP_ENABLE", 0x4004510f},
{"linux/random.h", "RNDADDTOENTCNT", 0x40045201},
{"linux/soundcard.h", "SNDCTL_TMR_METRONOME", 0x40045407},
{"linux/soundcard.h", "SNDCTL_TMR_SELECT", 0x40045408},
{"linux/ext2_fs.h", "EXT2_IOC_SETFLAGS", 0x40046602},
{"linux/msdos_fs.h", "VFAT_IOCTL_READDIR_SHORT", 0x40047202},
{"linux/if_ppp.h", "PPPIOCSDEBUG", 0x40047440},
{"linux/if_ppp.h", "PPPIOCSMAXCID", 0x40047451},
{"linux/if_ppp.h", "PPPIOCSMRU", 0x40047452},
{"linux/if_ppp.h", "PPPIOCSRASYNCMAP", 0x40047454},
{"linux/if_ppp.h", "PPPIOCSASYNCMAP", 0x40047457},
{"linux/if_ppp.h", "PPPIOCSFLAGS", 0x40047459},
{"linux/isdn_ppp.h", "PPPIOCBUNDLE", 0x40047481},
{"linux/isdn_ppp.h", "PPPIOCSMPFLAGS", 0x40047483},
{"linux/isdn_ppp.h", "PPPIOCSMPMTU", 0x40047484},
{"linux/isdn_ppp.h", "PPPIOCSMPMRU", 0x40047485},
{"linux/ext2_fs.h", "EXT2_IOC_SETVERSION", 0x40047602},
{"linux/soundcard.h", "SNDCTL_SEQ_OUTOFBAND", 0x40085112},
{"linux/random.h", "RNDADDENTROPY", 0x40085203},
{"linux/mtio.h", "MTIOCTOP", 0x40086d01},
{"linux/if_ppp.h", "PPPIOCSNPMODE", 0x4008744b},
{"linux/fd.h", "FDFMTTRK", 0x400c0248},
{"linux/if_ppp.h", "PPPIOCSCOMPRESS", 0x400c744d},
{"linux/fd.h", "FDSETMAXERRS", 0x4014024c},
{"linux/soundcard.h", "SNDCTL_COPR_WDATA", 0x40144304},
{"linux/soundcard.h", "SNDCTL_COPR_WCODE", 0x40144305},
{"linux/fd.h", "FDSETPRM", 0x401c0242},
{"linux/fd.h", "FDDEFPRM", 0x401c0243},
{"linux/if_ppp.h", "PPPIOCSXASYNCMAP", 0x4020744f},
{"linux/soundcard.h", "SNDCTL_FM_LOAD_INSTR", 0x40285107},
{"linux/fd.h", "FDSETDRVPRM", 0x40580290},
{"linux/soundcard.h", "SNDCTL_COPR_SENDMSG", 0x4fa44308},
{"linux/smb_fs.h", "SMB_IOC_GETMOUNTUID", 0x80027501},
{"linux/soundcard.h", "SOUND_MIXER_READ_VOLUME", 0x80044d00},
{"linux/soundcard.h", "SOUND_MIXER_READ_BASS", 0x80044d01},
{"linux/soundcard.h", "SOUND_MIXER_READ_TREBLE", 0x80044d02},
{"linux/soundcard.h", "SOUND_MIXER_READ_SYNTH", 0x80044d03},
{"linux/soundcard.h", "SOUND_MIXER_READ_PCM", 0x80044d04},
{"linux/soundcard.h", "SOUND_MIXER_READ_SPEAKER", 0x80044d05},
{"linux/soundcard.h", "SOUND_MIXER_READ_LINE", 0x80044d06},
{"linux/soundcard.h", "SOUND_MIXER_READ_MIC", 0x80044d07},
{"linux/soundcard.h", "SOUND_MIXER_READ_CD", 0x80044d08},
{"linux/soundcard.h", "SOUND_MIXER_READ_IMIX", 0x80044d09},
{"linux/soundcard.h", "SOUND_MIXER_READ_ALTPCM", 0x80044d0a},
{"linux/soundcard.h", "SOUND_MIXER_READ_RECLEV", 0x80044d0b},
{"linux/soundcard.h", "SOUND_MIXER_READ_IGAIN", 0x80044d0c},
{"linux/soundcard.h", "SOUND_MIXER_READ_OGAIN", 0x80044d0d},
{"linux/soundcard.h", "SOUND_MIXER_READ_LINE1", 0x80044d0e},
{"linux/soundcard.h", "SOUND_MIXER_READ_LINE2", 0x80044d0f},
{"linux/soundcard.h", "SOUND_MIXER_READ_LINE3", 0x80044d10},
{"linux/soundcard.h", "SOUND_MIXER_READ_MUTE", 0x80044d1c},
{"linux/soundcard.h", "SOUND_MIXER_READ_ENHANCE", 0x80044d1d},
{"linux/soundcard.h", "SOUND_MIXER_READ_LOUD", 0x80044d1e},
{"linux/soundcard.h", "SOUND_MIXER_READ_STEREODEVS", 0x80044dfb},
{"linux/soundcard.h", "SOUND_MIXER_READ_CAPS", 0x80044dfc},
{"linux/soundcard.h", "SOUND_MIXER_READ_RECMASK", 0x80044dfd},
{"linux/soundcard.h", "SOUND_MIXER_READ_DEVMASK", 0x80044dfe},
{"linux/soundcard.h", "SOUND_MIXER_READ_RECSRC", 0x80044dff},
{"linux/soundcard.h", "SOUND_PCM_READ_RATE", 0x80045002},
{"linux/soundcard.h", "SOUND_PCM_READ_BITS", 0x80045005},
{"linux/soundcard.h", "SOUND_PCM_READ_CHANNELS", 0x80045006},
{"linux/soundcard.h", "SOUND_PCM_READ_FILTER", 0x80045007},
{"linux/soundcard.h", "SNDCTL_DSP_GETFMTS", 0x8004500b},
{"linux/soundcard.h", "SNDCTL_DSP_GETCAPS", 0x8004500f},
{"linux/soundcard.h", "SNDCTL_DSP_GETTRIGGER", 0x80045010},
{"linux/soundcard.h", "SNDCTL_SEQ_GETOUTCOUNT", 0x80045104},
{"linux/soundcard.h", "SNDCTL_SEQ_GETINCOUNT", 0x80045105},
{"linux/soundcard.h", "SNDCTL_SEQ_NRSYNTHS", 0x8004510a},
{"linux/soundcard.h", "SNDCTL_SEQ_NRMIDIS", 0x8004510b},
{"linux/random.h", "RNDGETENTCNT", 0x80045200},
{"linux/ext2_fs.h", "EXT2_IOC_GETFLAGS", 0x80046601},
{"linux/mtio.h", "MTIOCPOS", 0x80046d03},
{"linux/msdos_fs.h", "VFAT_IOCTL_READDIR_BOTH", 0x80047201},
{"linux/if_ppp.h", "PPPIOCGDEBUG", 0x80047441},
{"linux/if_ppp.h", "PPPIOCGMRU", 0x80047453},
{"linux/if_ppp.h", "PPPIOCGRASYNCMAP", 0x80047455},
{"linux/if_ppp.h", "PPPIOCGUNIT", 0x80047456},
{"linux/if_ppp.h", "PPPIOCGASYNCMAP", 0x80047458},
{"linux/if_ppp.h", "PPPIOCGFLAGS", 0x8004745a},
{"linux/isdn_ppp.h", "PPPIOCGMPFLAGS", 0x80047482},
{"linux/ext2_fs.h", "EXT2_IOC_GETVERSION", 0x80047601},
{"linux/soundcard.h", "SNDCTL_DSP_MAPINBUF", 0x80085013},
{"linux/soundcard.h", "SNDCTL_DSP_MAPOUTBUF", 0x80085014},
{"linux/random.h", "RNDGETPOOL", 0x80085202},
{"linux/if_ppp.h", "PPPIOCGIDLE", 0x8008743f},
{"linux/soundcard.h", "SNDCTL_DSP_GETIPTR", 0x800c5011},
{"linux/soundcard.h", "SNDCTL_DSP_GETOPTR", 0x800c5012},
{"linux/ncp_fs.h", "NCP_IOC_NCPREQUEST", 0x800c6e01},
{"linux/fd.h", "FDGETDRVTYP", 0x8010020f},
{"linux/soundcard.h", "SNDCTL_DSP_GETOSPACE", 0x8010500c},
{"linux/soundcard.h", "SNDCTL_DSP_GETISPACE", 0x8010500d},
{"linux/fd.h", "FDGETMAXERRS", 0x8014020e},
{"linux/fd.h", "FDWERRORGET", 0x80180217},
{"linux/fd.h", "FDGETPRM", 0x801c0204},
{"linux/mtio.h", "MTIOCGET", 0x801c6d02},
{"linux/fd.h", "FDGETFDCSTAT", 0x80200215},
{"linux/if_ppp.h", "PPPIOCGXASYNCMAP", 0x80207450},
{"linux/fd.h", "FDGETDRVSTAT", 0x80340212},
{"linux/fd.h", "FDPOLLDRVSTAT", 0x80340213},
{"linux/fd.h", "FDGETDRVPRM", 0x80580211},
{"linux/soundcard.h", "SNDCTL_COPR_RCVMSG", 0x8fa44309},
{"linux/soundcard.h", "SOUND_MIXER_WRITE_VOLUME", 0xc0044d00},
{"linux/soundcard.h", "SOUND_MIXER_WRITE_BASS", 0xc0044d01},
{"linux/soundcard.h", "SOUND_MIXER_WRITE_TREBLE", 0xc0044d02},
{"linux/soundcard.h", "SOUND_MIXER_WRITE_SYNTH", 0xc0044d03},
{"linux/soundcard.h", "SOUND_MIXER_WRITE_PCM", 0xc0044d04},
{"linux/soundcard.h", "SOUND_MIXER_WRITE_SPEAKER", 0xc0044d05},
{"linux/soundcard.h", "SOUND_MIXER_WRITE_LINE", 0xc0044d06},
{"linux/soundcard.h", "SOUND_MIXER_WRITE_MIC", 0xc0044d07},
{"linux/soundcard.h", "SOUND_MIXER_WRITE_CD", 0xc0044d08},
{"linux/soundcard.h", "SOUND_MIXER_WRITE_IMIX", 0xc0044d09},
{"linux/soundcard.h", "SOUND_MIXER_WRITE_ALTPCM", 0xc0044d0a},
{"linux/soundcard.h", "SOUND_MIXER_WRITE_RECLEV", 0xc0044d0b},
{"linux/soundcard.h", "SOUND_MIXER_WRITE_IGAIN", 0xc0044d0c},
{"linux/soundcard.h", "SOUND_MIXER_WRITE_OGAIN", 0xc0044d0d},
{"linux/soundcard.h", "SOUND_MIXER_WRITE_LINE1", 0xc0044d0e},
{"linux/soundcard.h", "SOUND_MIXER_WRITE_LINE2", 0xc0044d0f},
{"linux/soundcard.h", "SOUND_MIXER_WRITE_LINE3", 0xc0044d10},
{"linux/soundcard.h", "SOUND_MIXER_WRITE_MUTE", 0xc0044d1c},
{"linux/soundcard.h", "SOUND_MIXER_WRITE_ENHANCE", 0xc0044d1d},
{"linux/soundcard.h", "SOUND_MIXER_WRITE_LOUD", 0xc0044d1e},
{"linux/soundcard.h", "SOUND_MIXER_WRITE_RECSRC", 0xc0044dff},
{"linux/soundcard.h", "SNDCTL_DSP_SPEED", 0xc0045002},
{"linux/soundcard.h", "SNDCTL_DSP_STEREO", 0xc0045003},
{"linux/soundcard.h", "SNDCTL_DSP_GETBLKSIZE", 0xc0045004},
{"linux/soundcard.h", "SNDCTL_DSP_SETFMT", 0xc0045005},
{"linux/soundcard.h", "SOUND_PCM_WRITE_CHANNELS", 0xc0045006},
{"linux/soundcard.h", "SOUND_PCM_WRITE_FILTER", 0xc0045007},
{"linux/soundcard.h", "SNDCTL_DSP_SUBDIVIDE", 0xc0045009},
{"linux/soundcard.h", "SNDCTL_DSP_SETFRAGMENT", 0xc004500a},
{"linux/soundcard.h", "SNDCTL_SEQ_CTRLRATE", 0xc0045103},
{"linux/soundcard.h", "SNDCTL_SYNTH_MEMAVL", 0xc004510e},
{"linux/soundcard.h", "SNDCTL_TMR_TIMEBASE", 0xc0045401},
{"linux/soundcard.h", "SNDCTL_TMR_TEMPO", 0xc0045405},
{"linux/soundcard.h", "SNDCTL_TMR_SOURCE", 0xc0045406},
{"linux/soundcard.h", "SNDCTL_MIDI_PRETIME", 0xc0046d00},
{"linux/soundcard.h", "SNDCTL_MIDI_MPUMODE", 0xc0046d01},
{"linux/if_ppp.h", "PPPIOCGNPMODE", 0xc008744c},
{"linux/soundcard.h", "SNDCTL_COPR_RDATA", 0xc0144302},
{"linux/soundcard.h", "SNDCTL_COPR_RCODE", 0xc0144303},
{"linux/soundcard.h", "SNDCTL_COPR_RUN", 0xc0144306},
{"linux/soundcard.h", "SNDCTL_COPR_HALT", 0xc0144307},
{"linux/soundcard.h", "SNDCTL_MIDI_MPUCMD", 0xc0216d02},
{"linux/isdn_ppp.h", "PPPIOCLINKINFO", 0xc0247480},
{"linux/ncp_fs.h", "NCP_IOC_GET_FS_INFO", 0xc0286e04},
{"linux/soundcard.h", "SNDCTL_MIDI_INFO", 0xc074510c},
{"linux/soundcard.h", "SNDCTL_SYNTH_INFO", 0xc08c5102},
{"linux/soundcard.h", "SNDCTL_COPR_LOAD", 0xcfb04301},
{"linux/soundcard.h", "SNDCTL_PMGR_IFACE", 0xcfb85001},
{"linux/soundcard.h", "SNDCTL_PMGR_ACCESS", 0xcfb85110},
